Rating class

Constructors

Rating(int _rating, List<String> _issues, int _tip)

Properties

hashCode int
The hash code for this object.
no setterinherited
issues ↔ dynamic
getter/setter pair
rating ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tip ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited